#!/bin/bash -e

APPLICATION_NAME="Image Viewer"
BUNDLE_ID="com.github.aliencoweatcake.imageviewer"
OS_VER="${OSTYPE/\.*/}"
OS_VER="${OS_VER:6}"

# darwin8.0 = 10.4
if [[ ${OS_VER} -lt 8 ]] ; then
    # @note 10.4 is required for duti
    echo "Mac OS X 10.4 or newer is required"
    exit 1
fi

APP_PATH=$(osascript -e "POSIX path of (path to application id \"${BUNDLE_ID}\")" | sed 's|:/$||')
function check_bundle_id() {
    grep -q "<string>${BUNDLE_ID}</string>" "${1}/Contents/Info.plist"
}
if [[ -z "${APP_PATH}" ]] ; then
    echo "Application path for ${BUNDLE_ID} was not found, trying relative path..."
    APP_PATH_TEST="$(cd "$(dirname "${0}")/../.." && pwd)"
    if [[ -d "${APP_PATH_TEST}" ]] ; then
        if check_bundle_id "${APP_PATH_TEST}" ; then
            APP_PATH="${APP_PATH_TEST}"
        fi
    fi
fi
if [[ -z "${APP_PATH}" ]] ; then
    echo "Application path for ${BUNDLE_ID} was not found, trying default user path..."
    APP_PATH_TEST="${HOME}/Applications/${APPLICATION_NAME}.app"
    if [[ -d "${APP_PATH_TEST}" ]] ; then
        if check_bundle_id "${APP_PATH_TEST}" ; then
            APP_PATH="${APP_PATH_TEST}"
        fi
    fi
fi
if [[ -z "${APP_PATH}" ]] ; then
    echo "Application path for ${BUNDLE_ID} was not found, trying default system path..."
    APP_PATH_TEST="/Applications/${APPLICATION_NAME}.app"
    if [[ -d "${APP_PATH_TEST}" ]] ; then
        if check_bundle_id "${APP_PATH_TEST}" ; then
            APP_PATH="${APP_PATH_TEST}"
        fi
    fi
fi
if [[ -z "${APP_PATH}" ]] ; then
    echo "Application path for ${BUNDLE_ID} was not found"
    exit 1
fi
if [[ ! -d "${APP_PATH}" ]] ; then
    echo "Application path for ${BUNDLE_ID} is not exists: ${APP_PATH}"
    exit 1
fi

TMP_DIR=""
function command_exists() {
    type "${1}" &> /dev/null
}
function extract_duti() {
    TMP_DIR="$(mktemp -d "/tmp/duti.XXXXXX")"
    # darwin11 = 10.7
    if [[ ${OS_VER} -ge 11 ]] ; then
        # @note base64 is available starting from 10.7
        # @note base64 from 10.7 uses '-D' argument for decode and '-d' argument for debug
        # @note Payload was built with make_duti64.sh
        cat << EOF | base64 -D | bzip2 -d -c > "${TMP_DIR}/duti"
QlpoOTFBWSZTWf1eD5QAbMn/////////////////////////////////////////////4GHd3WGvfafXpjZw74MO+zoQB9mWmr3utW2e47vfZo7755SRB69L76Xie49dL2PvvrlzvufZ9W69e9XjZ7zXahIxWW0qB7u6IzWbe7yepevXPh9nwAewVYw1UrZWmBJvXdNb
HnAd2q+s972W089vO3YbVvd9rrT3fYZ3udfbLPppbc7vXOTW4eg53eh16HoH0+gD6elKHXOWGfYHrkF2GWug6Og+q0VyfYpu+7yk53eIeeW+cN29vu7zzuu881AACPe+Lx6F6yvptsvfY3MqiiQvkMBeHrdRYDm6lKElKu4zuWnfT057OuEqIggAjTCGABDCZGCaE8mg
ZBkNNNDRoZDTQNBPIZAAMmTIamaJskwZAATBMDTQ0DQAaaAJ6TAJgTCm0glEk0mRoJgEyYCZMIxGEYjJiaZNT0AEzTRphA1NoBMU9PSYIwqe0YKeRptTFU/0yYNIGABE9DSPCExlGTAnoNTTwhkm0aFQanoQIEBMCDSGmQTExMTSbIp/qp6aR+qe1T9J5MpP1JvVNGj0
eqNNMT9SaemKNBp4p6R6T9Sepmpp7SntU0eU9Qepk9Rmpp6jR+k0aj0gbSZplAAyZAAAAk1IhCNTTQ1J5NMTAmkPQT1NTxqp40yp+Q0aaYVPJ6DUbKepmqeKfoyap+qZlPynhT1RnqnpsmRR5Jk9MCGIZPU0jHip+mknptFPKe0kPE1P1Gk09Mmappo9TT1NqHlBEqFB
J+pppMNAU9oUfpR5Gp5JtNNqm9EynhNNNT0mZRtBknqPRqNqaabU9NI0M1PTU9Q9DCh4owg9Mk8mUyDMpkAMg9RphPUGEwh7RRkD9IajaEBUkhBACNEYhMaNNBoBMZBGNCNNPUwRoyNMhkDQyDTKPI1PVHtNMQNTZTaaTNNSeTak9TxkamRhNoQbU9JqbTTamp+kPSbU
eoGgaBoNRob1Rs+1s43QNxUn4J4Lx3jchnMTR1GwVm5hmt6UuYZbLla1IpDAe5oEQHsv1f2H3ceI4c0Q8zPmK06vho71w9dLQi+QI6SsjIFpILRS4ZAlSUN7J2nkZoduE0Q/Fz8B+0twuUKqOAaVUINSQ3Hj5RhazZkXqJ1Vaiy8KuD1gBCyLiEcSSQhcdBApZpqUUNZ
dPblpyWv7b33D8DLRqFVTKqNdqNJaqaGqqiqKaVapRlUoKsppUpi1VFVVDBYKJSlLKFFqjS2WWrbF+aO53Ru77HqVSvZG9yMMETj2VEdTSnH4PomwWvxq8u5Gd+FzFjmVjwcj0PYRgP5W1mLckgKPRAvcysRUNMZ37iuaNx7hc5oNyau0retnyXW+MbSadAEUa6mwZ0L
qLJA6eIOmgCh2UVVqiSBaTlIPwuVrBcHsSvM5duLVJiqQ4tLNxZwzjS9r2Lj/SLT69SThaJVJMWM7HsrG7816jIJJYYT5n6HaZGh8RxA5FJJSsIGZSSJxro7Isvefe2YYEmWohhJvaxZRWRaLRUhTenlmJcvpu7lqY17tbne/y9/vfs/z/E0/id5/H1eWlp3l0Wikvj1
7VMeeo+XtcKjGdetWWvvZH7PGMzOby90zoxqrF76JWKKCRRKH5S44ikd2cM4Njdgxxy3zbMlTLuWlV96r7d7+bfOC5lpzcvRUvuwvg41A93QzepGryrmBgmAoaoGRQLqwrxhusMZku5nZm/Gf2pUZ9YmgV6k409Q832xg2XRaRmX9gb4c11Be9CYvcnui9oPXFpv3Cnu
y73h70tO9r88rngjAeWdBigoVxMAkyRANhRDqsMoLkdCBDzq6gKMzjE/hjFxXjNpmU/Deepd+Ln0fp9rRz+wuYPD/XE63T685YRsvku28nRNzPbU7RDZtDEiydC5Z17WExMVlTS+tc9JTVf2xjPKLd0jdo2AuNQfTza2xzrbebey15FOGltwWK3AeFtQjXRbAsfwThpb
I4TiJD6vyzijaemLrRTjPh+M6e8dc9TjeJyFV+vLpf3ub8hZptX6BjnnD5vfLu/nqz2q9e7M4M+ib/9IwnBepLfTK/9HNZ7ZF7G7Y0+nbyww8BY788Mq71TNdLRUfnVZD0wqgJzmNGNqlDFOy4tEpAUMmGbU41r4VA/EZzPvu9x7+3c1nrI0xLaalkUpA2bmTBA69k1/
2uJ+Xown6KFtHc27pLl6f/tW9B/otMPiIVD5ne2sBpflO2TzDNnJISGxex996ZJNWWenbCcE4rI6glDYmOJ3VMk5n0p56q8WaBatoNGuFy1avSwz1DQrZCqiEIRVUiV++qjtdznZ1FNFFeLo332rLPJt5KxXvJUUJRRRKUY2/G05z3mjRR0NnVVk6emmc5PkuGMYt7uF
HwYx7+uEK7+jVV30YwpplKUN9JHxjHAZdCUnxjER8HwJS2MpNHf61Gk+fBnOE6/wJznfyZKaa6qu/poxyltpSnKVUpRjGMfKuylJ9mGWk2WUss60snObSkkpakpPyak5znp5qKMEpSlc2+33Pgb7dFT3BCkIFQEoUCIiiqLaqGiqf8/r1LjFFGBSooqqoiIiiiNVSKKu
LBxs2siiqLSUNUNVSqInLyi5UMGHAQyZFBiQzECadptNvyHI77MSZmSHG95UDe6tHO7axMdRUSGjOLzLb7tbYkn6dJ1drCGQRv1bvTbRW/zHQeSgX6AWEUXMRQHrYoNMFTXQ8S1EDOMgUwORqiSykPNsQosrFEYMQFBQEYKbzKoeF/VUOXZ+cgZ9jg1XxwdGzs+HradP
ovK8HS3A8PH1nW8qXgS2K1UWXm7HgyybIjHjt61abtPyOo3WnPufJ/2zX3usb1gTzzJvntFITYQhTAWQSzJNmVUJfVoCzGIbZFg1UkyYDhUAtGS7Ckgf0eTqE89x465z+z+XbZ5QNDDT0uperXOu95Y7E/zTCHtMaDMwnSsJN/0xe0gbDQned1JRLHKcM4GntORi2mO3
xeENXegb93Ct3HOdtRmtrxyAb3ibMMfpONvZU6yRt1UbZWc6ghz9FxmFHTbncCl4XPz8OgpOh2C5/5WBdBdK1oXdwEo0r4Gec+2mMYag2DYaMRitxz8DDRszq53sVqzZ7Cl3B0ND02TlXbuyyDiNRp52DXhXx5Wqar1zQxDWIxlWOZUIKoWReLRr6mQJxg+nk6Oft+TV
pDAL6aLttoXM2Psbmg2na2+mI2WYUjTdGdmxLM27d7JiwuwZEvZU3GqMzBNJ+ltNbY546o5SENA3A16clG1xa0qqydZatbCdljw1Yhcnjzpzw7hFBysg15Ot4EjCtUO5xpRjSzDCm3hSBOqXkDXIdfLnVkTMdslIpSDbi22fuqMdUc1EguzugX91gutm0zrUbrR2vWhg
MRvl2rqVVsMcUAco3jnW3WgBogAMANBCoDlACovbD0vq/EVpCKuchJR0LASEfGXqHg5GDH9AVRC2ywoijYNhAwZVVAoZCkkCkhUSAKHK+FQbMBh8VDATyqdAxYZXrPVaEoXDH1btg20e6W3/iEbsN5vdrv6LC6oiWTd73N05hf3SOdlIn022zbenFuZzG7BGYEXSNogv
KA2qt4veda1nC1LShEAkYUQXhD+Hyn+X5H8WE874X8/1fedXyfRafUeRwDV2mxUKRYiSLFRFXkqjqZJppVUOzmDOeE4MSjkJFb+ohLXZw0U8hJVJdJuVVMjYMeWsSyCPEfKsszyK1rB6fi0F0PlpZNBcoFRLNMMzyh0SVrVSINedtl0OFhj5+segq6vL1COOXsEWtEx3
3qxdCcrGDyiPKm+UcwoIJBNNO3qqqqREVii4NXrgNkbUVhVm3BvYVlVmYsUJRATlPXKwGf6QIK+Bd6rNb0HxxX8VTB2UEYba0XU8tfY33F6tdESRl3qJLWIbDYXHNcFYjxkFUHkiDbm4s6UKmX6HKQNkiwDsQtKGwCM5CqPQu9Z7pgEOh00bhA9R3nU9peGsEAZNuicv
F5WJeIBioIDfjq8F0vQ6fvOk11posZ1f3OQswHoYLquDqrInlKkbgSjfa2FITyXh1qVJHHedfad1berEQsopbxsiKpXRFoCKiXiAdZjdnSmqk1vk8Lx2bhIzCpI42pMlByVSSa4oYUbW3oGdck2rCGgwKJ0YlA/QGbVm/ZAhc7mjOhLnkc35XmYT1LPujg/d6+tovW1/
icPeZTu72nLTAGFtSnPewtZzNS6aKLlJHlKhJPXeLddDwaTFdYNrQnGvnM5wKUp3DmFh8NQ/SU9M1VjMkM5Ukj79FngKWUpEhxMAH0fHrYOj60RVwXnfbz7/LvIAgBEVSyBGCWKiCQQpPvpHh2w5gxmAfpg1g3fPN5w0tepkw3W7ywL6WjHUrAwrRovfIKGAeYYYpJD7
fRc/LSBpN+VCTMIWEBOEIcIS0OdYKAshRcuWh8M4ZgJS3qAm0RgIQGAtjA3MQEMVEkIjEqQvqQ7OoSH9/NctufYfl7v6Hc9rt+Tzk12tsHN1m1NjsdB42GyVCTNgoKIkFgoaMIcqagLNOOXy1S4OG4EoDM3Hm2h/zNUn8UHV5uuzHBzPtiefanaqaa35/n/f5SOw+3hz
Hr9/v+WL+meeEevNWFlQcGVHKUOM5n6SnjPStReuYKfsOHXG6YLMTpX1mRgYD2joVnTc7mXL2IyL9FVWUjABR56DyR5ItD1Ih+rKNb3j6gWBbPiC8Oa0RcGEcwYArmDM9ZevZyl5gZVy4uNexvkGowaONWPE1zNZjWZMrEszlmJTIzln77Be0V6imYz1m4asT4NTXqdE
qKfHotJc/8rkxrylGi0l5ZRUVCGZIoUhBwhA+Ae5KEqIvI6/I8/6P8+H31tp+m3T41Ofv1v66vgzft9yERIUFCfxrDlqWK49a9zpGvBUHYT4wOwEsckVwhqwUEJebNPhnisqc8mJmSbwt7lmgSHFfHPLlB0AzYGIeypdTrdP60vJZnOe7wn73vvp+4+B33WZtHgM3cqs
qJRRbE7q1iV74aTeKJQFjQejzSi2LVFZLnXZ/RUfmSrhXLr+v0fZ3yH+Hd6OF2DtGAa1ZBpkyZ1jgS4CguchG6ZCcl3tQNkjhKEZdldFawS53u02mfAttfTen4V7ZH0vHUTehKQVU4urQ9B2VEg0kTl8huPQnpIoeySqPpVWEN20lSlnyS1C87OuvmKReVoDwo3ghA+g
CAiFAg4WgqvTDq7dR5W5ZMM1J8+08e1srwwREcKM+OiwWQw0VmKYahP2Q16NXRo7Zb8+VXJXOPxxHHJacXytXu2TJS/ZoswpfCCKIQYvCliXo+KPBVYoJGSQi8QUPKwaMhGUZKSj0KQEnlGJKSRHI8QCxeHqkhKMSxECjEgQD1QNJUMAVioSSSlJkgZPDzIUxrDIM2GO
GJk3abXpG9WxtVZYmRlaGyTBCNwozNhJx7CyV9S4basqsUW9IWhu0MmQiwggIlIaGmap3uGnW2Wa+Urzla16lMOpwvfXs4Hn8LZu+qsdJZwDK2rnsBiyG8dokh1nks9gN4m3SWTMb78axdFPGSGtjurUMIcD/5UMk1MPY2ulxr7WtZDMqSRN9VEOHrXKiKUaNHzHFfBL
Qvr7fgtw2STDMdpad321b/LSVUC1UEWHP6tQwqLWUjTAnb2CAqYCJxsVfpRFL9E5oi9pOb23JV41+/SbMHbjNaMhNQQBZJFgH+tOzR/R3Vg9peiSGDMLFBJyghAzJA/SZlUDHG+ru1TVUgf1q8PH4z2l1fNHgOJo7LdcGzEHb7uhEW1wV/uKJ3XSZXm/Ew/wxPkr0Zai
ZUV9K4xaiUJQuSND1c67jrTf5/K/Gt4d4iISe9m3gu5psFP5Nr+eD9uyddv1OZ3arr3arjs7IHckORZ2rbiC8dbVRwqQ2bYbJUwYqN/lss8046yTKKjoqiASq1oEQP6Yy6BbRiLYFe1C1qBcIwlFJ2KpWq+rArxY6MIcXI+Ts3+ftC/suHHVBrxFSiRUilUN2Qb0MArM
sM3iprxwsx+PB6vjgM08f90+rxO1Zy8V8vpXbyeVgejdCZe2LIR5HqA2hqqQcAaBQCPES0NyyJLhcpDs1jBTL5pPU7fG7g3JKHtzcjk+4zSaCjO0vhavGYPjU+s1hlWUS5Sih2Yl6y4zvu6g2+I+VzvkkwI+HgTUzULKZxYiQ0J7pAA3fLQgRoV0PagoRNZnP+YHBuSZ
dH+dZF+vpP6Xb6+T3IIDWPz6UcTDDQJKyTm2mi7Urhuubem52m8eTB8EUUlQYNj4Fa0rSVQesCVZNDe3CsesLpBMrsNjC4BsnJKK8UqRYwQVMr0FmffFuJ9lt1kw4Mdq1cPFuTMza70yeV/Uar+5YuIp3tY7Rf9bfdWT+9yzbaz2nEtevgt3L09pfi0+m0QmDUDwgeXh
TuFlYyGtTO6ULfSRWTwsdmLtiLNGXr7N3wynflVhm9o7AqCQjQaL9yTLEdIupqyzAx61L+/sqcwpfEyQz+isBfHt3ljLtmZ9d3WRsXLEwB0cPD0mDrulsb3wT69xX5mMwnbuRBpXC9OtE532KZItohAaVUaUoK3AKUPE0Hdj7+sol7AkQCWCoVAqAM7169LitMVrijhj
HLSNqNMZBSnewW07NnGexGVW35NvLvnr8tP5m3bx+b3G4b0pSZSufoyLYM/e/z8zjS7hq8n8c7nWR4pvyMPvo7BW1PjnduYO26btsKrJHblVL2vWYuk/djsVJp3ijisJ9KSuxTv6Nlv+NQ3G8fT0d50o8Re5mP+j9gIyk8mTwe4tKku0vioLGB0W65midIWI0fedQfBw
CWodAtQGgneV9DeRu+fiOWJeLp97mXqncnxu78h371eVNOT45oGtOoR3kUVSlFeFxURGZYzZjKkfxnMfJ1/EUtGvNTZ47TQtxwtFqL3K7m9NjY/N2hvvXYSFVXol2N5EKjGIQBeG9RHrsJSKlmCqegsgGoM8uKRLCEQ51zdzLEi0DoRCJzwoQgbRlQ+ICjBCOzzautz9
BeaxevXr4xjGMYxjGMZylKUpSlKUpSlKUpSlKUpSjGMYxjGEIQxxxzZvg+9NWHiTZVxmvb8WuyvPvvFTyMCl6MfYH+NewKEIyEIFdsgfSyszlWTuzR1nWmwhVV5epp5wOX9Asu2O2DbO3k56Z52DNOt+f8S35WHAB/Y8wYWoZ0fqZNCe3C9HyDT7W8IgGxCRBcbihQRG
wrBvmz/mnr22EpGqKvGprmiYk+bTHmStp/300l2NLV01PDXXVXqrkZBoMU9ZRW4puOxWqkKnuA43HMw9RuNlfP5smcsNO911q2Zyub6fHVcCCnfS/u/e3e73x1PwPLP2uNY/7XFG5SIldVarWfqP7+Eq1YWl17bmp/CXpFEfTFoQasftcbvvlb3fGHvzvC7AKK7xcO5z
hbVyAPOcXMw+WjwzmuiUEb5FN0B3MACWaLnBAOxHAFlVCCss4USivyNYvgOrB70bByN13+UxpngLgvbSVYekawBzWQD1zZhyCOtPPZaC8fX5zT6/Q6+UjfKj2iGU4yoiKKwUSGs2IOEFN+0hgkn0GyDZaAqIi8GgpUpJlyZ7Hmb/s+PjmLmfji5aA8LpKNZXrkKfLnSn
eHlhLnG1HR8xxfH49xii6kmpTUqq+A+P8EJGqvGzIpJCoa3Q4JKQhuFoY1yibvkwLQCPF64mh8SbtGA/aQM8aNJA2wPh1VHmEjEAECrHH1j6Tt7uzG/gUQE2ug+e58f4+Pwrvjc96kxa9+5cX0FwzNbmI9sKOHHNN2bI+55ovLCNE43ytG5eOSyFjgPOytNfGgSlqaeN
llBNsqFuqdVUC1sJSu8Bt5fVpnpgm5b1ip0vgw1BfcBum9xrpy9SVn+cZ6GjcXfyzkV5GRlp9VOdtkYdrYzPY5RLoY5UDz27d/kYwBaoYwtooGSE/ISWJ55jWHY5MCSsHN2XElUiYFk7k6mpxeJ7P5IT7rFw7gIh9cJlzftbk7L+mhqibkFGLJqrNecB/wXYOFtOyqQ6
Tr7Hqe4s+fQeCpHuI+qR22ToHmQLkoMtF6hmIOvMgrZFR5gQD5kOBJr35LOqqcfTy7Xlob4rr+csaRU72tWvfUdtROAgXcKXNYLWMM4oh6ap6K3NRKMVBQ0l4bgPjbqW7vX6Cmj8v1PHwt2kuJ6nJ/0GI13I+Tyf5za2g9n1rqmawE3iLuU9+qNrcmv677dwU3+tP2fL
y6x45dG/TWGyujwuXA84MOIjFVaX+RRiNg2JlBRyYjTVGTnuTt+pwfHyfw0N3ntl0rTDervbdl7fD4vesZYi4SeD0/8gb1SWyEteDjjGAGOeybLMAj7AWmpzaf+/A/7ncFw5Zxc6f6nLt6MHujV+yUS02QGzMg+tc58ddD6Se/7uiaWYRlZrWhtULv90+lDD9K/1uboy
WB053AVkX35/RrW4rDejwAYHRJmYdR5aocm9yqlCqDBgKOVJZAzgNJTikkKhbmJ1+rfMPs4e7f+3mrvPxYuB21O9cN6i91ivB/271xutR48fquZ1JXT+TO+zdSj/6PJNbGKc2N+4v+9HhYl/6W2/bj7DJR9I+8UthwYGZvtctrdmk2f/s3mP78/36uz/q2bzURGvifv7
2qyLqR0xt5hIm/0/P0U1mslMLz11gQHpAxm521JsYP2SvHmB8ougepBePFoIM4oTqyfRJ/UfXGU7pexmJz5PAOR1vq3tGJomwar9s6xth0R991Ije3wFPhvNu2fUdI3s8R7E3o7Yc4ZRDEecbzDgsMuPRjDmMmvdnUEI2LYtMUOoZUhRZeNF2l1m0XWl1E8a32vWrR4l
J7hxfaQ/ov5HquW/aXnS1ru3M+gW8LeYPlNRS8EC0VVYZci52c30vXE5Mz/WnJXE2tpgKuN8rZb7e4vkftxOfw7l2szq9P9JnT7X5Xi86jY+U+vY8uToCqa/nmOL9ZLjcrrW7f9qf8El1t1XqDHqsFu61X91Xpdv4NV4ig7LAUi39wdZsAbBpGmgkmhVLuplwUv2cUK4
F5chWYDKsoqZluSj7Ym7mQU6C8EdxJNg9EqgPMNjJUgv/Y7YpgwvJwFUIyQlDh0e615Y69zy7AE7dtMvYl3fz+DebK/WHAPztZfLi8f2LRT3mp+exyjPIgieWaPtEmi2ZdpHUIlcu74snX17JiEOtyxRAv+mr5oCM9Am9cQ2LAMPKQzK8TT7xahAx8JrYv+FxpSc2Y0s
zAM53QRqADhDgyKj9u44MXZO3ngQ/YBx/j9H9ovhvLHrVo53sc8sVBLAfP10jLxZLxeRe/NnKCKx2LvHqN/vvmT5hPkuJSSpTQ0bry/KXIHIoa1IZHOgB1g9pSgjM5uGpxhA/bT8gPlZuFFgICKCAeBNv/80ioJEgkbCY7aizlsQCjn9csDGcKyMhffvNFcOAWqS7vfN
eCK5pS0W0jcJxTnZzI6L9bNfGUtZJCQ1IkEkGYEmBiLgZVjf9vqWficyyvNv6mqyqY2e9isxsrEuTBRSlyyyndN4ZrBZlXs81joOQsonU9R0PV8sVvTgCicWy3huOpsT7HpWIxKPq5FzrzZLkcsuSfMEPJf3s/gGQxtEcR7M1Zy/PTsy3MFe0Rzt+hCjcO8o79yhwPlt
NrsafF2nG5/r8vBxd476+mhum2knRu+LE12Rtt18O/hxlSTne0xPJ7lYPCDhFXzlQFUktYdIchA8retcMM0ZA1DhAkbvPEBuuFID0CWQpEWEBcs3obXddD3fL+/0uvxqGdH5QuSlQQRBPUIcZQcBzxxTli76y5u6TNU4xz2e3pjJkXJ5xSf4vMX8ce1FHQXIUdFN1iy6
wC7xZAo1nFCdRbHddsQ1vHLWOZqGZhwsy6Cwni0559v/TxXy/lvaPrd28P0j4tSAhAigiXXKUlJL6kJ4REIQYiB5mjfzSG1GTkl5/2Q8syB2EggYcgCKPUmrhz9fcxYIjG8OoZJangdpXkU3nN3RhkgsyC9bOmhJBSKSMSebtYLu3WmqWYXVP2nv4dr/24CRwNC8QsSE
9ACJQXzGiPgJewSjHJTi0iwSIg/3to1GivxkCbb55oGRAcktx2WmymbGmDLLfSFLfJF223iXk6Qof0FkBswGjHtpWHUumHsfhzmK6UD73Hz8hzdL2+tjel2reIzXfenOVcxbnzsdcPpy3v3uBgXEC3AuYF6gb4CWMeggUYIvKnAGAmpFiQmC/hk+yGDc9oNbTD0d0+wy
pRHRclqnYDb/EdELCawSWyCwOnaRpcG4Z9vxNtAq7pTymn9RoNYrapvFdqOVGKGtvx7gfe1aOftXT9T0eMENNBW7klcybHOvEnBUTKq62PX1u1juS+9yA0lH3ZiAetnD7aLbtN09Vzqld17vNu8+6z7q+OorC1L6E6F9tGgscAHjXvw4UhwhOXrh25oKGBYrHSUzTFUV
BVatUpGytQs0nwNTAsftHG93b8b871dv3TkyUnd8bsw91JHWv3n8I99M6p171Sn7Cjb/b+Br73isksy2nL+9dN3x/x4ePbmztpHnYVDl8/HQXv6NN/Y8T6dO1Njhqqvs/PbsjVDfeHeNLqJWZ1n97bJ9veY3kZGfueOq6TyuDpM/2p39aPDgiUQeys8S2ErTBwS2YeSz
hYQJ09I/WkTPHFlB+N6RoQi80Ld7gz489ldk539Lj2+P4/1cvHY8OyLHbkSM9pMJURtNVUWN79FVzukz+TofZW2v0fL3z0s383mNnbmnKIzVwQtuGdcS9NweU7Q0PLs6uThYm1710wyY3vZ3QtiENj9mXDikndrvIZZd5O0OUeTy63aLzg07FIWHGWDV4W82teuwu11T
O6/VL3nMwyrQQ4J1LohEyIIl5lxagEwAJiC+eSCauf2QImBNqXNiCOwB8TMvV1wsxwH7BV3lmXeABKPZGjSqqZ2ymLnXV9XNba0vMb/ynj5PZWG57HNhDU6u8cucMWos4xxf5d3VqlJcD1fGxGDdPV5ET3PKq/K9i9Dt39mWB0dY/k/TynNDxtVj8XBgusvRpzy/QfdY
sTG/iNV2x89hicVwX1C/nvaMVuQkHeF2FVuVu8uekXSDKVaxVBZmFq+WCpfr+JyB8/zp/PnLU0JwPFg4KCeHRfnTBjTX+7AUE7IH+Dej0K87J/mdj/Iy+Kt/wuaivtq39J8Kh8+5+BX0Fce9/ZtAqo6R3xnMht1/Ps8L7P/b/fZigrDK1q1llO328VbEQz4xiKE9FmM0
OHEnu9FtDU4D4In60sOG/dBndvOQ0CCTJ6JATKJmQzEsUuL9ulND+G/LFwqGvn/o7dv5XnBdHm3bF5fWvln5NoztfRdMpE2ovy2zszrmLlDLjKFtU8iln55OeP+iXR942ctE5KpOC/AW3mp5id9Y9gZO/Kf7RpTWbCkHS8PblIYQiX4LgOwilK8WJWi8nNSC2qplVnm0
cgjFgsNg8p1NvDezyH3dcHbbrna7lRWJk4Oo07CfqPA5TnEhareR/AfY3HnHUw6v+s1DVCcdj9h+ihsgfovpXfBzNbV7Z1ENt4NT4Z01Hsnzoh60Rdh8uhoaNNBT7gTlxsM6IU0CpAqmLFLcVKpU1q+oKjspwYJthTmm5G6qlS90dM5yWftunWxEhDWPOyUtnzyKZTay
PIe8VeQ60sX8+3/YWMiHtThIFZNuyVgWRSJ59Y2d3WZFZfdNzOpdYYRczUT5YC7K6CF0AvLcrWcdfOg1H5Ow5IomLR5sIrXE68dG2m2GwkJL1Oc5+Gfg5Sjtnd2o9tc36gO/geqZsMvzoyc1oS2FPwM4KDej2n+h2zxfLaOw1v6C+JeEi3Pee2UWH/lrlon88Cs4vD6z
7yeledI1veXbLgIfYy5wulfaUj1MzdRjNFjy0YET1sHMFcXqerQghHcqGAsCCMv+obrwIXNOhrI2zQZy/3i9xRJ2cx1/M2b/Gdh+tJq29q/WWL3MDwgrJ0nXKdAvcX9d1N00/mCUs69cS0fG9sxJkvmCZ9AMRQS9KDD3lE83gMdL+ZqWf7mmYcE5QIxPUaNHnQgLf/x5
1jdHD64KcWETWxDfQ9QK6hNRDYkO33pQeShCfRVRSJUga7/PVi5G2/jmXvz5TuvC4Q+oMdrZsErSn0F9+EMuF+uvl/kN3okgupjw6l2rIx999/pCG9JsCZ357M8OzunHpzKm+++9co/m4Dd42rrz4+t6M1wVE+hfScvdxfUxLCridlu4HOrkSYiSHC1iEe+v951sfRyk
QsPSfyO5T84J13Z6av7zO9iT3niw1ABGl5bH3YSE6lT5r0CEd5UFQ2VVulXSAH1sURgYIgqojZU9QBOXFaM0sWQTvbQWpIWSqcAaiQzvLjTZQLhaml1E6XAIlnJtiwFxIOSuwXK51SlUAM+20Ab0BdF+iu8HQg6kATuqgFDlKqFUKWqhosNJUs441W1TLZTI7+wFZs7R
udrp97+DsusOuvJBBbJCtY7wcmoOnnR5s/BD0hgBwxzJpAT6A8a1XVrs/y1g757DAgB8Wcnz58hf2YVEFZ5NRhMTHzvYuvL23HZbtcykaM0NkFlLfJLrkXSiZYVAQ+P9HhRvuPms7R6P3+l0r8LqXy323IpR99iTdxc/QLLKUopSf4vjlLksxLFP+34Wg3PKJY3nilLO
+ZCHSeQ+SpnpKWWUppiYnOqUpTmr72kKRNQxL1l68mJryw03pWuUxH6TSU7FTiGR/A/gPx6JkGaKGsWGqL2ewRePD2TBezRQ9sMYXsqUpH9tlimC9vbE5RrGNmNeNR+VgmYpNJTSXMiZ6xSizYuyabSY1M5Mb+65cyFi9gvSyj+VjFwoYmmYMQwZrYr2VPiqZRojIssz
FLMTUb6wL1zGvXBYysxnu5XjG+cMYzRYucAwSTBrmg1W7Ptsoxte5p4y5c0mtNEYPpeyUlyVvEGHBT2RrbJpByjXhPOS0dYXdj6mXe03ITI44e2uDNkwSwQ8OwEpdYlb67X3LXvHC88Gs7GN92xpr/hPBS0eIdoy/pVHfNP+Bqy/aMEnxLuagGhx8dOGFJM9pD5Ke/39
9xqLOHQbyfhlCysG4wqKoLE6QaJPVWHXcDd7m1iC2sxD/gnjLM2QlMdRbE05iTth/YQgIugaYFxgCdHxaW3ijEVnXFB033THaju46lTpyx1bXiHdYRub4UF8JZycr36NpPkoMzNdgQ7j9QhObEIb1kqFQ0yPLIGWiTRNJbiM/UrLdYA/6qumUxpvSPO9HnbIKK++CtV5
KgxVjWMJ1jUdV3PSYjxXpPbUlN2x5EgIkHBZ52eFtzzrA3T23YcGIZtEjoiLNKvdEUGN+wujT/Q9A2Ed2pU0z+ZkZSeWGLhQl811cZHaa9ci/JNB6G0a+IFmFBtVUMkoYhW2o1alnDlo2nS9Vp9NvrsT0qHHafUrmyUjzyg1tJZSLjuVHiqLhSlImJSxSc96xyey1rgX
Ufs3D6imrUc7XUlJ92ocxR8unINI3Hge5zv0fiX6WwUAxWirjORw3ZvgNPARkSZCEMqAjBeP0NRBO6VGvPWQGRdKSL2aHkDMUhkY6PJGNI855IZD9wegrdlwvxPyGXZXzJ3Mv5ZYC4i4JEQ2Yfbm9yBoWuE8Z9vQZgOiR+n57Cg0W+mP7sSlpoulzP56qlMyDDl9jUIq
EKSxTYsStWrJ0vNuu75jlWHYA+qfNwrz6JWeVQusVdpZctXgp6dyZorRZBC9xfWOD3oooz1XE0pIEP089SUzmDieQNRGovECJVYXfwlLzHNhVglQ+0oYQlCdr+JHte4iXpq6pWu8ETK/eV3JwlJ1Qbs8kNEbNa/3faa7zYu4w58nNvQMhIqmysfFO3QpxvGP2/7fwRE5
YCgdIEUJMx57u9C8n7A+OgONS+LniNHB6AQ2AKNLYIbkp5lmsqp6A+/3wkoY2HOxXUPX9CNldLprcEoY/XBriRERZLZXaV+3+2gdXQkWXCMJUpAKkYGIHLsUtAiTdecQxlNTkMYgY/uH0hXZeDzYc4WDgQgmWuW4W9+N/2kNmQW5JndIcZvJyjCHClmDEfgG7ZEGIvg8
iTydAww2FiPIKHYUPHDyfhJUu8PO5wO081sohlkMsSzr2eT0Psf9XlpPKeYyVEJbaeacrbS0nuE38U5U8lEp/I8wT77gZ/mjiHfJzLIEiAWgsPDXypGU1okXkreQdt5a/SacgPlCqszRNHcYwfL3Esil80dO9MhlXiX/gPhMK2MPEEcOAxCogKY5IR88wCGQ+4ofPLLK
UucGpkTarkq9/rsk+MmCfIUyJx1ycV2hQ/gFD5LheLRIZf6KDGGvXCCvGgCb9J2jJwtSSISPAuz9n1Ewsacx+qOzU0WHmXXGy0dQ6pVCG6X8iaMiE4BIjQ+64REh8Pow/k8QxAj82esBIOQ4iKAYTTHKGVltIyiw3IXwM1V74gusHpH83IUwIRJ25xL+IRmz3FsG8UBC
85wck3R9R+c+96ci49TYOlbofYMR844A2qpmlSqqpVFFahrmod2J9o/pfae+P3nRJ9bbf5eNt01DRfK0ll78DiEs8+1vBsBcp3anzin3lFvXvWsQuXsShiLsmBmsHvDq1jn3FNJuHuu0j63L26avzDxG/ei8A0Oy/31Rome8n4vsRz7ExN5s9ApdPK24hTMcQYO0ObHV
PJcoYkcidA0DNJ8VzLWOGOBcg/2VOSK7zmIENOXYqBpMCa8Iooj+rK3lqO8fI3RzDtCpMjkGZ5LltIMk6Mb/FcDvmrYQwif2loJ28t3zfCiq3NWznat0qNf1pri1nM3WGsDrepe/hTQZSevjHWsSTtyXPzqeBzJxC3ck6f0HDE8FosCdO9o4N8Z+HExE0yfw2Tsjqn6b
Jwz7KeP61uCmsMBcsj1wweCNByFEwXvwh0C05+YWyO4OXdJmLr1Kge+TCyRhjllodzK97PjyvP+t7jh30H/XD9g96Q/8Pn0fxn9funpCqYK03Jx82Eo2NOFL1/nMii/xym3mqcjvQ/LwZR5/8vTYx6exH6+MRDtPO80IcwUaFDGMYULEonVJCqr2bt1Ey+HiRevv08y8
jobGbmPg/5KOIPOOVLyLzeQEkiQwJJzCLznOUuOdXHOmIvS7IY1F5iS5ZMKpK0FAVD5aoF4sF4KBcyuDbseSYuueLssoQlWCermIwmkc4hg2PJtLwYI5x0iLrcb4Zmy1EOHkUaNbvWJ3z7uvz+3i5epzPKiEyCSzbIjoaEly9WQbW48++DkjJ0J0LyCOAPDM1BFTjDZf
Y9PYLPdoOd1vtDBP9A7gYvCFUTYNPB7B5zmXy4Oc+kGa0VdXV2RY8/8wD+/oW7qvP0floefp8XoX0Ob4ByzoRwJcomS4uOVLvEFCnGBsEinAfqO3oGj+5fvK7ZjTHGFeppY0hyYtdgNwinS3tYF7yIcFyjor2CNKFusTE8CJeUOE4HAsuBb29vbzVv/O32GAkHdjW+nl
dVj7y1jV8CMl1QsgcJ4YSwYgjgYFAoKhpgS9vXKDa85oPXvkfwle9HZusEZqg5/DqbCBxXb5qNynjoX7jtTG/KifEGfzcl5s8fR3prfrB7fOdj2dThoa0M8RVofqFcJU3H2rPzWAz7WjiqOjs1HR0dHlMLR0dHR4+gslHRuLnGRF+tpbMU4835d1cBKhkltL7YuJscQB
wNXNbz9Q7GkHgGFiD0XbrWhDrWmGhVgRWQxTnWfKlpZtzpWSlTgJqlpM7S6HMzjtO9IQ0aKDZ7L4BcSgrKgqDVCg9PUcQofpLZl4yNv/cI/iBncVqsJoDl4AkMZTA0wX8CUIjJXmoFWR9WO0ImN7y915A3qwYISYDd3iNdF4gDWvSkFwXryscd8j/w8tDZOToZYGkyzR
lI0KFasRbUoHGfK1mCWeLc0yck1jKKEAU8CIwgdPNjAfyaQk4n9SFMeTufJykG5jBqZBzvyuPFMALQ0cROT9FUllMOzg3z+jy36wGnF+q88cLyzl+6u3q9/O75Z6lSWfzpYvUjcqYKRQoNChZiCgoan8Zc59pvx2UpyB9MkU5j7jy5aOoB2HrnD7xI8jdFxNyQbwG/9V
2vX/UGzE6azEpdCato/IeYqHQI9wM4SIuTmgocb2n8lsf3DR3uKHOVverjQfxZuTDS4c20JjMCI4KMUd/gu7G8qdyhzvr1OMghjOcoKFslKfvi+EGoaZaI997WIKRI7JyTlTId/2d2y/THVmPJ52eePs4Hvnj807YPWCMIzRKmMT4yoCXwRL1qivTJ6cvETse3KM6Tim
o1tKf7j6zaUcwE6wmujmocUNKhRoOyN01IIbTLelfdxATctVabrmIUdqKoKR4fWMGHDDynOt3TzaDo45SPp3yuWEwRBKSEllxmJ+LCUCUiDJuwJmTQgipDuxjpfxzd7iUmOHc/jYE5JfoMXve2kge6VFYVM94B3LEqzXRwvTXNSByR4Wo1ImU4oMnwe67Z5G3OvBthe3
+HI5MBlBwk/mee8njbtzLHpNj6S/MdrdevfJ6W3uPA6+q7feph9zcHtNokejidXaj9qVIpTBoIRWfP4k1x6lzo/TDaPzcbbfDNZznjA7bDevw7gQ1kOQn3uD4p3nrfXfl+xN/zfMnNNNVsrVw61rVDC1BLFvGrgtXKvRjLUoooYsk+MwptcoRrFyvLkMGepZTIx7i3Rv
oaGbTYcngsjpSv83lKgLJkU9LQWx+fajxAeNJ3+67h/N+y5zH6ed78Cwe6H5FVDsUnjqoPwh8Mk+VSKtItMWM15zMIf8N0fkzixnsJ1vIgT15E3RP9E3h75iljImYzJ9dmktOB+HlIYcJj43Y9Z0B/0YL3NTY8gcJ/z8Q8pwVpa22lr/lN2M5nK4+llfl4266IqKhkmD
EVbzfd9Ivhb4Ae55076ipoyjVv1S+02CZqu6GFMoSccMOe/Fw2urvZ/PFG2mILIdHvk8mmFTWnrnsJ0MZV/FMok2l3JsNNLmGjPy33fNqbueCFdgYHuHOXo1VMW5ziVd0uSr0/FcvqMaQZko4a2lSLjpt1Xp98fY5GSNbjaTgm8DkOxLE+f9r9Wb/JKlA1DBgc9Qx0mK
MMVwIb3PIbh6Bx7B3CEdMMYMYxz4F3aGwfftLS0ti67k70Zvs/8me1RwrhtC4C5CDPjzphIlCPBJIyXKluR+cxLuhXfIGgM0Q6VjZk/gOgkuA5tuDzT3LgjZ5iPP4eum8S9ZwaqpSqzZafwM9OGg6qNYhajpDWNpUo6l/+jOCs2mf6+yWwKTEZWAIAIzLHUuX9F57pQ/
wPoe9kfx/voujip+6T1caL68n0aY6BcL72GadV/jQtI0oqiijGQlK44H0MG+swT1cz/YrnylPJvJ1TIIwRIpMUfKZj7PjIASbOsVCX6xS2yIS5Ujnc7DHPMRG4j2N5SB+pMUZhPwfb6iKiKiouj3gb5ocEoOPEgQr75+hySwr5U9j8CmLLDXNADqipsZFgnTVAC7qIeH
rEnLvLzq2RVd/Oo9fZ6gqm+yyyq4iWWKpY5EhIjDiLlMGsIyRptqbx8J/UDYj5Z/9lb/ZE3WvWLVB4THu941YInA/Ge3nt5mzNnmpY5lestayeb4Z/Yc4TT3XnOTPwXsjuNyWQ5NipW/PuIIqM/2gKSH/u3SlMpYTJfghmUmEui9RlKsUQBxBZULZYCiEvwio2j0Rf4w
/1eaa5zy8qOhVbsY/M3gEzvYe6yTyjt492EgYv2e30mobJhOzoqeaQ4T64b/A629fyYbHtqyEZg7hK6/Q0MW0JIp7uFRPc0Zayu+3X63oHbOx2FVkTKo5P5vuML8ULBsHpBkqSgZWFHqqFYwDtAz7BAw7QIgOUoToNbFr4xAph3/utbdYUvtvi2gTp/yNNvF41ex7qvC
/lxsdpm7ZmW7L+R9jL/OaS1/Dz/2PZ8SFZrrN78H515ux81J6nz6M9/oYqFw8BKH9v/jttpAQapiVN1FXDyHCWj1uWkBOGod1QAvCp57m/VDigwfn4i8Nwa9KNZPTyzaRHyfNW89N1Ac07AuH6I8hM45q+d2vpnuECP2SHcD7NPquVhPKdHXfeg3vAth32M0IXatRVqw
bLeqEwpopWC+YnEN83DpdY9+s3avfAiW9T45tbGlREwKomTgvFjiQQ7f+Yg43bY6Ysmco0xH2+XIXhna3E3KjmeD2cT6rNDkFwfb9t4WP/Ue+hLsjDGoGXZ/qbXReIoAdWrgG3n2XQ3/9GZYTaX3mqIwYV+wuHD5hun+nYDgnwha6/4WzXe1SNGqNQCRAhs5WvGft6af
EOku0T56ey+o2KShA+8cIvIdmx2DsMOZhvojsXKtLeSoPy6+veMdDhLDMQ+C8KANaUbpKH9L9XKXdOZ9ClDDKGc36l37ol80SIJbreS1RtQSS73+6w8oKQt2mgLozlpmGQt1WoFtYmDhC+2rEFP974pycqU3p1+Sye9MzCbgpBp3w/7FHrbpJlENhPTMousOw2XvWA5J
sC7KhfGxgsXt+OvyBVDBDkaiEO0dQOTZIDmRl7Bf6CpEN2kMpKan0XMbPEXr+GJCLhbCYE1CzyY6YHrSi8cwIb7tjRqNrf5+X4PmviRIKkveTMRpLlK5BoBFRC6B9ZYCbPLAeeFmj0QIbt+3JiK/aGziorXud9Zth5qpr14Tlirs2ZNth3qMzdzz0+Afdg7YxJ5yAJ1Z
T0ebZdVsC3JiIjXxX89g612nDsZpzuNtuzrfv0GKG9WghSSeoQA31j8LPew7PiCMitvsGdc/fcc5jRQxEjscd2DTSkVHvHJOVcUchF3MoEQjfAiIHF+a0CiYKzo8ssOYtckr8JF+bBA6iNAf+1oOrEh9Rq3l5eJpTwaWY7ZPGRuvZH/jkmYmiNZii7t9FTvuCKStBHBW
mGcNJjU1Esb/NCZalPBOPiAXHcnm7dCWGvlkRMaUQPSSvpBR8OiFKsmz0OZcsv5jG+BLgOt9h7jOR3qk6byLJ4U1f3G1zIfYmjwn67hPpvqn80Kz90VGGbOfzS86KSAQPP1TLD/us+biB7uQ65Kcomx88gVVVUBRPdFv7LD5mHdjqmKL6SpvB4Sb+NUGs3AX9CF6M4VI
hXRGYM3jRD4GxdQ8e5DsDEsmv4y8yFpMTf3MMTPPuKX6zU3yFLMV5k/XfF55hA6HW10jJwu6uu0PWPzb/5O1taQ7aH+wftQolUoie6KIhHKnxEe56RfstO2g+3bF7Ak3DcKdAw29MWZLPbVN4J3TklFN8l0/GOhTFPPPQvRp9WaZMNzfNvd4jY2hySpHF1/8KWvi9OQT
1WeJA8mOThzvtcUO+cs7nX2wYvP+yJpC0Q6I3WNHeUTx3TbRDyx6dVVSVX0uEtOsrjsSevm1c2eJfI6F+ApvCYnX8I5I4edsTqpecNOLQ9s3CZyTEg5/g73yfTNn5ZLNz/TjohIgwwiXgS7l3GXXcMxil3VJtjhppQMx0pY9vfbPibUlTrizqEnEtlSNnUM4nkZEayVe
Qwc69WcqnEJo7VPptPc8zPW6ac2qVlEsJMjBMphx3JPv0jXcl83oLFv3SSq2kQe1EVT2FleAwrtgMDcio4qjj6RANecdiENqV4byBIdrGiSFnRpdn4WWxLtVkcYuhc9MieOzVyaKNb10OLlJRKT3/1vdsh82yx+QuQVps9qrEAv+wUceGFuLYjB9ZgvC2gsmxBNIReba
hL2hA9F865n1iEcEuSLgIv4j4kyNG6OuWGBNGewcR8yk/1vuH+uyNoRkf3djp0CSbVjK3NBT4yNREcoEW6SIgvpBsSRJO7HOpHAnCPwmN8s67pzyPiWQGg53otSbrYc565NqSJIEkJAhHmiACvnN/eyH1+x4exf4Lioir+Z+Dp4Fi4iIhxDJU0yTKyiGSJlp1QQqSMS5
1Bv9F3hjdwHn6dA/Xy/AgNIytZvmgYDOLa7/Mc7Rwb+VXgtih2ifFZHHMBWL5Wh1tlM9hB94ebNb3O5aCdCswxiT3y2gfm61uJjgjWvyDgKHtDfrR6Em7skMquB0Oi6vZVYu6PJkyfAqi1DO9M4nqvfRa96V9cyOrO4YeNPmUoKakI48r5ggI1/kiGEKl/Pm0j+YFYHl
sRpDS9NpDtqXMc7gyQeqTzw2Q1fYYBtCJKDouhGTFEeavlyWO5qcnV4WZaIFiEYmaAInOld+UP09p8GwuxccVRHjci+C/DGeaus6KIfk48hAj8sE2EesEbIZ3S8OIuzPE1Gm/T4ey1XanjnfmKzGDNkvAmOmDjRJC2INvhRsa8wUPX6fMCuXhwRjMiznKcECBwxVx5um
Wo/AP4S2vJAJ/LUxvNx8zb+JcvAIlMjo9Pr6jICNXpmgG8iYApKWg/QmJR7EgD0FFUVRVFmpRSKKKKKKKKKKKKKKKO+lpA8bPPzciXMjJFFFFFFFlACUiiijx2aELzqvmr6fLn6ta6XbJmYX6Cqa7CsatYwQUWKKKKO477MNOuWtliVqRq998uUFmCmLyej4ecc8KZGX
Oo6UuWYT0qWYXtlGG/MTAgWBZ7+UY9WTNLFkUUc5nHhXL5UUnyUpHOZp1hqxZPeTZH4VBnLmczoooooooo9poLE8RC9pSf10FkUUmzErNCiqwsaol0FFKDXhQMS14FFUSikUUUUUUcJYPVCbbxSipMTSCJbfEEODUVwdLhvPn0Kk0OoIM7CklZUaQ4m/LAgMPEPPEtZk
cmxrhfvlFyqikEqULHGzSmULzZsc1BDKL1ovIkGes16zzw9mNKUAGhZHoNg7z2LG4Q9ItSKicj3Plnh4X/W/V5sq0+eDJW9ZZxG/u4Q1QJpyBAyBQW/rZOJ8yyDMGKHmRzUkYSUnDk4iHOR0goCDBOrTfVnNusFwxXJnQrJXNcRoULLwh0LYmkj1VDiRrAsOggdUSiUn
7q6aEwRvHPT+ZDwkvRfsIz3Uzz4zJiZVO1ZXRvM0mKhrTMSiYxqzYTWNOaMMBljQRu2RkCoSl4zUMFjNlL0kXKXKRspExMT4eAMQkASh1xXNgjwjaaTbinaE6wch3LVBWhsDcKRgR9cwhrSa6zf46naSzpx6b9ffmSZExMbfo1ikWfQ9z7fYe18p432tAdGXOaSpzpPu
isFPWUHSM6b3B8l5GF+v+tgamn+Pr/Rf3cnpZtV6A6zkkTMbw2pk6f1H8mtx5cvIJvw2M3+WhC04EbsJ5DHIYDyw4ANyoXDYxntaj5Y3SpTQl0KGemjHKRfMa5gqs9Z5gTBnIoonJykzI0EwTUMTOnZ5WkXDNSwXEUDw3zNzZ5e+NT/MI0uF8+eMsq4psjOxKdOLCECL
MIRA00xqy5btuu2gyKJlo/ob0l6nyD7nX+TlYMRoBSzIpRs1yXLGkLJJ+cpe84tiTWprDBpd4ViYiz7vOXzhM8mZoLRYsODdI31SlxgjMZ7gjG6Tsi9KhjxytSZGsXTndiz2ezme4djzJprNcqrWUxMS4XNtkukkL2e/W4fVZTYRybfS4xqGYqW7Osb/X3TsfgHK83n9
B7wzDkFzfGyu8+pcpe6dQIIIUPGIM8ZBniI9YOSFiGERFROFDKZyhGRL7WZb7/K/5dlstkPRbjQZzRfVezvZ5orJBpKUKawLE6hcLhYYMrtN1rBexoUprk+az+w8Cybw3liFDBsWDZDgwqGpCoWJGsx2JVMDBMPRr4XF6cqSjytTWShL5UiYLJ3M4ZrJg8FU/Vl7rWNt
2BZlUDf6XTLG/rTQRnTMKgqWl0nFcNdIxyaLaCpnQVJKHFNfrzQVVTAUtM2YLoxIYlQyJnSFwzfzGcm9jIzWoZLqXI+MtZVRcN3YLkUUlSkqUKaU+Z52aI160mgplakutdqPpmfM6TOlTOk69KGkh+aQoZg9ALGixqrVHILzdmwme1E+VMaNmbEcAlPHhoJQnI3BfO1K
ixgoZozWqzCWm7pqKTdk8ZwCqOea8+nSxYs6odQwIfA7W52Rm/E+e6BgEO4NiATDqw61fDlwEJl/u9heUPi5p1np9fxnqtPxca0ps5s2sUpSUUz5EsulkVFla1v20gj7O4RhMTIRZLmCksYcRUcApDvhNtMMoxJY0gTOFQKDYWsRY5+FvZ4u5moUIOHRh6Q10q1bT8U7
O8W49YP2DguWeZ3vB0TmMszkvkm02l6c5emf9J68uzTUzIbRN+nNRyLical71WVFplnMGSF7xcCnOzjbb8f2g44C4pkKLzdabBHMk9CRbyG4HAbQJbsuy8xjaO1N2tOdm/5xgN6KUrfSWcJUWOSXoummqchJLhc86xPDLxhPs1CyQxSydO/pOvcup1zFlEEVoDHvZ8HS
d+wXFJTqBN0EW2e24wHk03Kc/emDijFyoMRMrMPVDb9Th8Sed+C7LZ93yvkE67wmf9LNiOMdUHjpQwSJShULx0I8qPXEvHGKn01JLMDjDYL2UOgVMGZBG4YYHomf8pzk6uFIKnLjKuip55rZmRNJpOdkYjkU6ZS5rlRFXoqWJgBSLUJBgwVIQCBFWDSlSNo3uz0OKawZ
GY569iZJw6Z8hrVKTrZnzrExotJAZENphM5z2iFpLFIhP2fKopTDQTwG25qiM5B5Pi0MkXAzpkjxG3Ori+nuIIIA9R4pWE4mvVs1jsvRr0VqgbwWo4V64fhQHLjYuAoHvdZd2YnnrmIC9T4jiIpRPoQKIGIIY6xEhxLY9sojcl4N4RtWkAJis1OdkE4OHmzBEH7GiD8q
QM6YzVSdUWXbC8IY8xIKyf1EzNzc3N6mfLTN6/a+E1hNmkK+BNmDLDE2YEY1tUQmZcjLmB5rIgJ9uqWJEAUcExScfHu4b3GE6iY0qKb84eVYwE5NRIss54XEWl0Ki9KPbS9LlykkpTJKlpEmEwGRyCY5C8ZYLNvimvORWL4imDoE62RqPWUXxdN51oymGQa1rVKpMkLk
6j4gUSiA4AzGVfwPR2pA7E0BpD+Py6GdMbwP9TQZSvfQgiGKoYxlbS0sLS0sxS0umy76FJ2Or+BgCaCdIMYKIoBeyFeyWnq6nJsxJeZH5Byp3NzOWmEZzRmzALBESWyrhQ26LyXzg+JTrma3LikxoymY/JnyLdg+EfrO14r1fH+X+Tzf8W++By+Y1TZFGkqJSjYrLFUq
lVase222222222223P8L33h52erQaK5IUKJSh0Ps7D8T76x/u4WbS6T0HBsyXBgibW6YgpZM6XBShYsvlXxgLwwkklL1y1pFTlci5jlKmAtIopCdZiPesTwsrNbypSj2TK512RuKxjzIWYt6VgVFBI3diEaWgYDdgbSHvEoZyXNRRSlMBfjY0ce/v7Dluz/d6569C5YU
Htg6KHzFaamZmZmZmZmZm9XU+D+dWAkkP4owRS5AwCZDAm8P2HpLL7nqQLkWEoUiGlRUpQqTIl1AI5ovsGoxNRelQqb0KLkKTGs5lwpF9AZRUgvG7Kj0szy9JdchQ1hfmkyGujK4ibViGAxy9MsylCYzBGCpGQj1ELpURZMB2CQ5olyNNimNmtSiqVUbdrSaiUZxnTAx
s6Zepeu+57L37v5x6h+92to2cL3pkTP3WylvJbE0F9P8QpEjUkCoorTT3haCgj6CgoKCgzus9LQ8HwIXPqCjAUiqbAHE7TAsfqUdCY+rfsPEJE/tfVrnHe6gbibhNuj0UpLOLWVPBepJJ+JuFUi+UMUof7PMtWM2QkwaCpmo903LAY5eLLc3OYIKQpQVDbKFLmBPMpyr
McKqrZ8uYMWwNBe0plFJzEXNeqXOXVVEna95+rrnuO4eyfc8j+N/vongeb/UKX9g2ZZd7T/fvYpC50/vU9PK09PT09Pf//PstbzI1wz1Mjf+AN7MU+c8e5cct23RdWMXlMRnQ5ne7Pxg38JChHOxbjv3L4Yxg50UGy6b9rn+He38mpScSrlFlo5RZZZZZZT1i5ZZRgWK
lql1GraGdZteJxOJxOJxOJuPZ8pqm+PA1yBtBC5GtLLJKcD5grvF7E87ih8tUvkmS0tMnqrkOI3mga4C+gZxdONJ1A5BNICYmpsnOsKmVxGKVF+YOcTZubiyphIc2nsYjTa6ZsmlNM3yZ8yy5OY0ZpUq9BeTOj2U00hdRLic/HoaMSXyZgqUxajWKac0TXJqeeNQayI8
uzFprBrCaM0JPWKFUiXyZkpaJVDSUkk164WHYyh2fpMTBWVLEXeH6x9X+NwVvRMrV6A4DqOf6rTbQlSOTwhwT9obEaIkhxgo0KMUaZPx8dPz9501620B1xX4ROAUTsFF1ew9Rd/acvbBGoMBqrh7VqizNXtqLl7G4gYL3eUmZu4xFxiThE9oxL0kbuYnrf72HlnH75NO
F9pXaWmtnQy/Ofta2NavxzkE4w0o5WG3EFLgVKhspLkwNL5kE4aGwYnmSi9rZxiHrnHXTOZZoMijYllRVJSL52mExeXNZF01De+FZIayYksM20SY0vRoi+Zl8pcLJ7FJULlS4qabOXLg84/U+W1BsWI+IzMi9Y8Io9v9yx4NT9vtyyeNwdp4fRPdLp5qp53uixNRSfNo
7f5+8m63bvnCMblrza76yNm4R5Vs2DDG2jC/FjvxtCPWe99lr868AHv0fWCYduJi8TxvHXu2+ppQIaDvIAdV6O08XQ1W7tiSjJprLmwYliixe16n4se75ti9vi5hMB9vCNzaoL/hzFgi1AqBEfv/bRdAh0HFwFtUcgdzJfL8Nxm4oakwVDIht7rfRwlphKa5GGYl8pHA
AZBiSUTtQ2RYnBMlkIaYm4OfmBJYHASTKTgxyM266GhUrEhmy1TRkY0TORJvlSTdhoJJMshv7UnFJM5iKS5Za1ISlSLBmjJHWsrlM5IbKjQmNlmWZc1DNYjW2pJ4kQQjIyIwgwNmS5kItAdNRJyaGEnttMZjQSG93DSNp/b7vYtz2/k7vzbufsvNsP0Hyj1g4z6FjXno
HNv1D990Jd9gjVSfNdHn85wNaNFuDXtqg05lgtaEb0T+ML4ssjphmfoZFq9v8E7o3A36jmwSdQfRSjAczE6JekQl2NjHJHJ/mpzB5s9GKOMm/zfmVxjHNkzXqKYqxGc3fEwZFJQ5M0vLzUbEhmpkmNOUuXKKKKAKDikhLYiXBjwLSfGLFnG7pSq0vdgIUUUgkpblxoKL
TrMndZtvcKsp4Vq1YAkme4UMgSYOB/gx+ORNk0IjowgYYCSJNRXANgRcyA5H0gRudlMAR33h/ce6/X/CVmRCnNWRkB78Ck6OHy56+5EfaiF3CloXvP7/ieRgqTQSsnj5IjJIgxoEdJtYIQuAg+xP4LmqGVCvOuKj9MFoYmxoQ37gmVvaFkeh/hQisGeecJAYiSPiYuu+
UzgkEJzhRNIigRx0vreaK2IcvpKHh/p6cKHvVU4ROvfs6FMZMfwxLebvJYikQUo0MGmDJXT36l9A07spB5+jwS+lmB1A58XtJlYhZe4KmCUQ7pPRcxka1SmRKMhakmuTwbwuKDM9TCUBafwB4m5PraxteV1T2AlubIC7kCEBTWC8Y7sOiwXFsPN7Aw26y/ACXptdrlw3
AoXY0lmSQ//EVsCgayaJXBzUz/KwysIWh9W54pxwS9Z1hDqDOUij/7mMcdetEBmEiNrkj2P2DglS1T1+OgxIJs+0pAHVbtR1EBc3p0dnlhpdhwQXOBQOohU4nl4ETfoLGkQ/oC6OfPDo9LHoDB8qS8uPKG57AhhmmyFDHR/tOXWII8uJgZ+RH+gxHVJwPO5yabZ/O+QB
VKmJuLwzlUz0srLSYWQP2ULweCDZnHg80VDC9bIn+bCw0YzFjsTDBfLgFxgydS/LfUCHS8D6oy5I9pHDwUYOJpO0S4SWgdvvbavrFtQFq9xVg/fBLQ5pRUTtsVX5o661dYVLTjB1Glc8yEexvTtjp3jW8U7ZoWYJ09g42mCiXwCkrQSKBobvXRL+4uIfGMMiu1qItpfK
ZWC/83x+HgOA9KM4+1QFDWNHAwrcFqxwxJTFpqqKKqho1KLQYK2ShRVEQMEpP0GUn3PzfU9/3+Xh4h1NZGziknZ3cxfLUaPf6DeVchqit/3S9NwiwUael47g3iZe8zDd8XycsFeLQxuuGaEeeGBf1Cb3JlLYEEVZYxUZ59QF4Yhj8APwcEYh0v6lh4sTsPwP4biXp1lG
PeOk421XNx29uJ37IUceS4lyXJQXEpLKSU9msmuKU4CyzZLL1GOgxUXthSylMFPmKWb1++9j6fqnyNgbS4YFUrzmeolviH/FhyGw0qEKWpJYVndnl0/4DvB6Tlgqkmj8nZlBGeZ1lAIFgiUSVWGLcgtEGXa+Bx9hSDFTMogYqGDNGEsETbGgk0m4TWaMrFUAnKqI0Zk6
9sWnW9jia2O02C8LBVMUyq0lrUzZKuN1fXuvr7RqRhCiFncBJWIr/vXeBPbSLkpsihFpPiJO6OCnpTqhI6NLWMv6h5qtpm9GwRmUrm51XlXkGp7gPsa8XpjNoHZHHmODPGxGHQ8ILRpPt9xhdGmJXgoYouzMTwGJuyYkKRES4lGrBQaQo1m8+U0IK37CqiI2UaGqoYjQ
tWLFvuT6iZzQGpaW/wXz/n443+1A0YhgfidAP12StOEEaVCjJOdd+CiIX7ixQY4dFQUjAzZefWAkT7AREN3Ja/1beQd69PzkbCCEIOxU2G3XjiqmoBnBn9oNxmLfQV3DwQxwXELpa1lBpeIndF/MSHF/GQS2sqW1QY3qPi9DyLPpgqSEHHtAiOP73nJ5fr+ePbiNfZCO
r5WDOb1AgnT+ybK249a72g5y6XZQpzdF/Xj0/Te8ocB60QxR3IwhNQ2Nf32oZj6P+zN3CB787H6eY2Ps6MpJvElJp40GEoRUOWSXTnRwwE6T3BjfCkX5LaM9yId2CE4zIH5MNn8OwEr0ySbrASoSySi9wtBa1MNBcGGHoy2SXqgpCe7mEqGsw8/oAz2MkiCRKUB0rq5s
uQyBEK51Vb3sCH3vehy/kNSTwMkGMBqDKdVjJPTBBG77/aesPiX6nu8cgJydFxS5UbYIiEUiohMLGU0kjQY8GVhbh+qBnKjyl4Urb8qiAWTbKTqKhnnNT48C3cDFhd3Zbi+w+phez7LKTSVP5eH/Q8G/T8Wy0qSPpvMO9/B9RFf/c3HUV3ptdXSkllCWQMp+8fwICb8I
wraVP72PBOYN984gfLW+fcpAxQZ+1z+qO7DzcXdYb7R5B6G/1lrp8TiMzfFoQmJgdGQHHDIpFIsAUBQ9f4YTXLkkuyRZIpIsG0eD5v4S8wqqkeU/DaLpUD71WpHd8k6L9F8H4R3lm6td2MBhOJWyzeETgnBCEcU10CXAwYrtAcBvcuZefHvd6RFnr4wc8UGXuwjRaICi
F6EIY/SFGEDzN6cpv67dUsZ6C/0ALTm0YYOYuFNoSjO7a+bLbuJM8oIBqgr6v141pzD3loxI0+ONKD4axYxu5NJjFL4wYJgF26lCgdksybh/tLvZ7g57T9IvDhqiXHYREi4RVRRQ2rmHmPjf+i3MO51K9oY8tYKGX4v8lgNRPuh2v3/GLmffUtdvb4/47Pl8MWDdn86y
adlpa7hbmwKOWrOrP1tnEPDx+dVB8GvAzZCiiqHYunlGoeh3joP+Pbluq+D3Zwv+RxQrjZa9k9gawuklyz3WBWwYdvVbMYnMTF2t/9dYNWGQ8o5SdDlnncH8/g84vncF/8A/4c7las1Be7/JkshV7Pg+8xl8rl5+Cb0m8tsZSr9+aOA97EOuOYoGzi5mO6BinVT95FN/
E+TDgQA8SsBiGPxrARDSxLBEOoqBoQVKFURK9aaiiSznNfnj1YouZGGlKi5v5yiWCgL9N6zCKBNGOf/wQIh5pWGRiPXiZ9uxxh84Wk2UZB26mmr9pTxXCwNHXDa4AgJO1+yzrwNEk+JsCvq+9sFBGoSiahmFgdoyTQmvVKb6xl0FMjhTOXRccvrZyXq4N6O6RdmdnxRv
GKcnGjMznYkpxdI04aZ8j6O39SrL+rtOyEFOrXCVsPO6JBdzP+IL85HIzX8BUrOquDOykvc7s1/03QnPyXVNLI2XYlEWU070E3lTfmyl/Pv64+pzyyoofA4ET8LM3G9UpUrcU2HWlwzJLl81xJFeOmx2N+s3LJzEBOemNDCdsJwHRtTjYa4tlco7RHyCQREBE7cqQ+Ht
0HHI1HDGrXd4inOwVVmuQ2N1JwjzMsztLDPhCEIxe8zBfCSQd3fYKCrVG3h+UPqMtbIF71hvS9AyW3Vhimkyzr+WqIM7AZ0tXdN80+W5O7g+PWcIDbn58hKcR6Qhjon5DNZTn6rDbjjEK0QhnI/jQm2aDfVSw6sgtfV6qi0/IKAux0TyC9c6oSljUlGTvDosZeBiQa+4
DYaEaqrUrg6PwJfGGysBa1gvDtyCgqJWDIY40FRxenAVehhixu17VZlWVwfdCE/QRc2s9l3CzF9Cwa46wzNA4sWsDLXd4Xabu95QMVVDIawgnGINgakzMWuao59vWFfqj6hhrzPhTECEvsnrdjfQzw4+pvfdK5Wsdg0foNCc4d7JjEblHYhs0flclrOkeng7mWGGKI40
jj+LiGsDjeN2BftIA0rsD1Bm8BDwc/A7cL+VE5I7sK6ltmRDNEmcvlPoOVmUer8rsx5V4ua92jGEaQwOvw/O756Yh6xBqSQsHcL8SA13Ej+7Em2m+jmNSN4/wsXq5PQtTS0cxNuBJXsx3srLWEcf99EDkvJpvswgh33rVmQmqgl+s15BatovgXPvgt0l4FBDqfK5YWq3
A+8EsClmMo16a0UN7fc6rwkyxa7bd4rqi1dk4oXMp/p15szjCxmf1BsXdj+CddZWEQfdc7CwopzmPxQBsJF5ATR1cRaDSjGQDTTGEC9bU7bNGP2vfgvf+PEk4O6yz49887ZNF13wUs32iO/q92pgR9m3bZn6sYYjG2bSdySqe2DjlCy+zKxoOyp9iI/plClC05KJsk6J
XBshH76R7HsP+u0dmU/cTIf8sk2GNjP8Exc5L5wKXQ2ZwLK6I5i0mlNgwDvrSfavM+LqdkTjzhs3fDRD5fyrVXGww8Pm6qqvcquvCjqDCe3V1okgMfn9TCh5JeVVQv4q//PYSritZ71qWfbgqtQ0N1/LCNI+WkZPeR5AFCd2CB8I9pGJExNQqPBZix+9QMz7G9wCrnPe
TEIwzn1PgocHi09PgySCHJnGZhvVMcLDfGr2TTehjbv7Gr0B97dfIDd9f4V/mH7+n+Lq9U0h5hu0BKzNjcmaT7zlcsC3zVLCMDCo6wpY1lJ8xi4RTgojEJYYqnFFddsVCtORtiwajTkOfoHv25IGzPxPIDnFiudL9zH2giY8WfXesdPnxFVkGuD40xof/a/UO2qHwIu0
rL9AqvBaeyQdBncPWHeOyxbUxLsPA34WdLf5bnRw0K89PIGeIe+Shl6ELkVp65BnBOJfuNQnL+kzJfPlxPxRWUSVxCje3axxY/C9Dufy37EXl6bUpivNQH+QaA+wRPULmKGlPNbKizDIYbMDoOH62qvfnUcYebr0l7i8WiwSYWrEA85BYcwzFejzqdMHX7DYPgdLInQN
bA3TaXWEcJ4sBhTqaDu7Dv7zboD9EBDUR6j7hG5eOfmpt8PNLCeo0VxijVWcD1mwGbRltF/9hugyxa+W1sA+HyrTORdzCvxyN1z1Mj82vaSNwww/dRHAez1StcB8K3rfs/8Lf/PMf4SBKjf6MZ0eqMR3roFmmqKp6Oh0dD6tGnxNtlsuhrrfCux+mrOb1tv8zNcLjuN4
ZSsoy0BzqvdF+nZPh8fVCeHPripqmDatIJAC2wX0YWU+C1Ahc6Zq62NfcwsVc4Ke1KwE1Btwxx2rq6hlYw98rKtJ2DAGqj7PeF1e0Yc0cPmbmRCjDplJ0ApIvv+0+C/Rj8gGJ3gQ8NmaomXZl+FNxNMxixcUXImbppipoua/ywrj1qriU8+SZQl09AwhDT5zT3D12KeN
9NZPmZrN6RQ8I3GC5cdikXj9Syvy9R6Syhc1WNhpfAHzJogTBrkY+HQeLQeD4xR8rwic3nLTQ6AvcS5jrZ/KFMo4VDVb56wE301dbZ27lC4wseaYNLLn7hvSVcZM1pybgj0DXrQ0+mpj4j+4Wa3Z9xQsIKFpGg/z5C0GZu7EMfkWLyMVjvQPbTQhD4NdZcN2ZIYHhPWO
8acLac8t8znLoZCmODDyb4LeYe2VEkFBaDslrg5ihih+3n9pqL2OiuqBsQ3N+jDqd36OtAzRszzykfjasohJFi9zk/AveU+c9k4d7mCHRxgCBSgc2lQPcljUtSbsZu/XbPNfQnNAPO2Dt42yZ/D9rDu06ZptwhpQf41IlauWvX0OHaioqWweyy+0Wtsek5fejLPphZTN
ccwHRPvlOYGI4wWyBot84IvAwo+1sVFZgi+ITYaqlw9G7NLvO093ihf2eVTMk9IiCqgSL2iQqkAzPkWoL+PbKpIhAlKA310fmWgTRpcyqpHExK9nw7mza3t/6nm5T3WE5w6I/6eyD9ja4kmohBVWKiB/1TV67wBc1MkMfXDVEwHAXSA7H+7bHana0OVQQnuiqgjaanJ0
KMry1Nu2FggEiXvAjbDMWO4C9pLua+PDAi1wgjOiMPjyVCpyk2FPGMeskwUuHb03m+5VZaTampiy5eYzYPV3eLA9b96ulAPLv2SIrx28KTQrzzu8u0Vgsah+jtKwxxa7flVm27URPwlUi9oRXnL9AKZ2Wg6d0FdNBmXt6+vCl1BWNUVD8w7zkPdG8Dt+szZz6uv3neIr
w9qfcOl2DwSCHiiqDz7qrD1tbGUasjAeJyAZeqgYOI//LSHgFB65EPnVF43yM6r8QpD5Ef+PbzhQcXPOghRNNyCqq4SI1p8VUOMPnT2TRBYWREWGBy565dza3CWVedgn/NwNvfcMAfKYP8WFfSlOs2Iym16TjueBNUJYJW92RW06E+AWJvW3sge2NrYhYlBty0h89lSw
+OGBkYfLqeceIb0f53jkMA4QMI9zi4LmWptawKl0e9oniJMr3z231tDhjGfxN1k2fA9puN/MTLhCOPSSnmxr23pOlB8ZtShHqs4QXHKOGnlLdVl1XuV3XHWFbqJzVluZm9G6N2S7PxN6DP8qck34z6nhi38n4dz3e9hQ9AkVrhRVFaXAqjmF2DCs+77RNPsC0O8iDSPF
2fCFLYHNwBpPoeU+de528vBrvaQm09HmNWzH5liY465vSamOXP0vfmip6g2lkCAIXKrCQ3/y04/vYZ+q/tq8BuzyHsLUEdEWOBb/zm4tZGVdROEkDNXyqCc4R9Fn/GsDO1gN9OdTwKTkP7FrgjAxWb+QnHVy12IyE62n98Qyy+zLfXLGdWmR9Wt31/fMjmX6HXpERjxs
UsESHiGKm13l2Zc8UgLzivhmhsvdSwA5hpugZYc8GWcv3WpOtw+oYz9zl2nuBoR2d9z6PIY+9+nI9w1vCz7B38p3JcL5h659kNeX70tpPxCkPj9gf4Du0OP4iH8oQiCq75pT1f3oisjD3VUdLiokH0Ln3Y2mujFiu8txW3slYvvu/rDnO6PODpPs2bEIlXPI3DGCoKdN
9BK8hVEbQrz8ya437hy+QV3snHnCsgdpqPPy08MtF16nhyTLs4cDe+bVpGIqn6ajBW8hcgKb5wRi4QUHmZI1AOUoskCY5DgczjcUF7ByiUC8B+INAcfgPGIxY14FKG4zpm2jfbBxkXc2CUWeqLgqIKcnqZXZikgKojzuBSED8zth9vqbVhc7G9fG9bJcDSlI/CmKjJHZ
Omf+pva51HZ97ZFSNB4Ba/CPl3Ta/8zT2L87UeYN1CGbvwNhaVlXX+lJxdrb2YxqhcYdSKc2Zc6EcO/7L276fhmdj+nZpipD5A4R3puNuMeQFwhZzxvOuDnqxSIF/yBsricy8lYR9WjTKT/RSeRUOx87aqO6enf93O8pJ/F3G7l0PJ+oWdaUCbqm2K78oSb3Seao7xuZ
Crd8WejCRYBlFAVRBBVA+5k2vmEULhckPTduXZm2DxW2u+uhNkwvRO7kOEX7t6vhOk2ihGxdxaO/gu/hr3Vn2mnMedkjNk8SerfU13f484S07lLggQExH2WA1NtLKOXVWx4e/PWxqbN6iRbjjmEQ4Dvj73w/2ZCz3od06tGYUL5oQqq+qre1Aycf5mzBlMxHXA4ZK5KT
HsHpz50V9mUILW0JfQ6E/GUW3Dq9JsZDzzgQU4Nra5IKDjc8mNct4Jfj/tHL+jHO+9PK4hu3xAdMotkwBj2mVT8eP9sH6sloe7OxsJ0ONG0CZta2CZkHLKCcOkk0lZtMwM43h/59ZUfNjfOB3FXEZjjV9SGi26W03w3TNuNDQ6DNfvvJ38abWxLZ4HTORMLx7o8yKQaS
1Gvo1RZFhlg/uLwu3G3QHtxTMx+ENHo8L82b/azEaBgvE9oszL8q1bC6N0fmMw/NrA2PSkof0QQ1a/tGsL0Y+z6KBLncOkVuU7j0aKkMFyuxW+7g2rEYjEOnVvnP3WfdeziZvnsVk/87MH+Ai7rfpGZR/Li+BAynHFhZXPMwvK1S4tMIG73opzPniF55+PFCpfQ0gKBN
ysNx/EqcKG3LifB1o9n8K+nviohkbD8qkvrZZV6jEA0OD/othF8jfN4v52sinLABeu7tUQBjiYe6h1rhBwiqb7uWbuKJrHwpqG/CkisBbiJFnTLaYeHwMVEASIMnr0ASM32i/xNn0qLlBsv3GppgFF4gtYvqwXr5w116+s6r0cJj7YZmB8QeN2/uRlGO25BnU8trsIDo
Vu8Pthn9vTI5qNPgDP7EcAbWzFr3v5m+G7xBQfCOHV0+nRQiUXoUZ2AYbbR9D352fJdRzPFMOUhgxdloVwy7CC7cR0d3/lxQ1NjpDGAqCvTmpsLUgsES8VgrbhnEbfMyUZfj/TbrHFn3ol7H3sH8a8kSg+Tw7Q+ua7VFEJHhCCrTark5cv+zKZprfm77YZLEEXDDomMG
Vkhuj7S09soKGDfb8yyxNA7jlr9/aiq35IdQInkmllORoyqwx+PkesEdxmWfS25kn31aLoReuxlxiZlfWnMPPUz9XfAPvhhZwUlu5hq94g6cJi40YA/HyGx77A62LNyTDY2f7UWV7AcEjoeMkcH627DHTjvoXqqixAYSJ26pp0o9gmbNaW0+DbyJ8+O+9t4ox8bcf9cg
cqy2V/3dLNQy0t2/mLu3147n5q12c3eTXFGx7EGq6K5odWTZHGLo/a2x2m/M9HsHxDnYoftxQe7+1uQ2KB7TG2MO9jhCo4sw7aLWG91lR5ExUZy7MqFv4QCQhWW0n7Xe+Rb6R958bzvmcGVHPq3XeXDx/Ms4Ri/8RcKpogXEzmPtDebV+jQcs+h6CV77YVQe6m3Wr11T
Mt0QRc7Dly+3/NhiuXisMGVa2gfisMBtwvfCa8PrgkCaPHd72dvNFT9A2tigtKLIpdfd+AnorcF+bsXc4Ta0YrTa6f4lIiAS4+h7X1C3sYgoJ6nDka2HoQ2o8jVF2HJF1VnPGqTe/hNnQQGR2EExF5Ff9qr7E2yIjYvCXXvBKjC9VS3c/qWbb2iuc9H+7zerFF+CVSKj
c4P4Geuhk0m+0IyRqwMKsWCxok2vkV57/LdAMu/RAtKY0vEbQvfZGp9py/gY9l8I4x0XrcD5r6yM1uCV9p3wkuw9Un206d8sJiDz0B6hxZ5oYeA2ScHxCoeuZ5gbs+2PjJ5Cfz4VtFB7U64oxUR9VnbGBGCpsPR1Gi6OX1T9hrXQYq61NAb/n+C8Lac3Wj2vqKsq9/2z
r79YgONA4G3xLrjkmGEqQttfO8Cnn6V8WszMhiFUoWJsf9DE5amKM7mHUm33lrVcP+kB9rM48oJF2wdyjpxIrsRU/Y1DNXYPDvc8Wq4MGNVUTwhmU94SmmBcCyJP0hovK2rs5LxaKhY3nOwH1R6E3GzwapsVVEEOLiDGdkJmxib7zw5J4BTsLcgDoctpxBoAdNfNBCYk
ri7bEn63KsyMRFx0Af0Ih2Y1YdTBC7rr38OKfTheu9PqugfLqGntN0woL9FuDOF932Fvu5KUkeAlxzVrsVE4c7VLI2+Zj83TkXKDLedfSEd8hvyQ6upryrO1gOaDUfzk5JziGG9QxdLZOwtJTsLMBY/3mBYLEKsJoCUcG/PEbiJ+hmnBS+zvDx1abm9pTGDHb+Lml8Zo
NirJX3wtt04Al9ofKBPtP2Mfme+CbSpjm1he7rwMyw55fYiMaG6oKn0Bj4kPMyE4JzYnNZvKnDrPZR+vKMK9r1VnzwOoazsEAFh2RbBQgkvOrYQyZ91vGtIfEZTAWEa+IDBP2z3Rn3X9mXeSPmlFSPSCc+tTQLFC/oUBK9evUSoKDsjXB7IGvjxwCRr7RxGbNkbZw2vr
1rVDoC6ntMKPRCQVwJkpanh33Qye83cjJBExSEI0KKqxSNSThy5cuWWMnvS6CGkCSx9LwYGiV7qGfmLQC0KzB6qIgQS2XrAlCeGEFei2Jxhq1KLjlblfuf9RcLB3fxY3p2YHlKXhYehJVBajJ9iXuOXGkdVwRzt+/Sw9EDTiLAw6Q597hCU+4rc3zHHm6G/MtpOCTfs6
N3s+6cbK9FiCEFIgpbh9FXJnTXPAUp6O28yfHnUcoPSKgoqqeSpKYSoASmhSjaDceTRFxauD6dqAA4bP2EuhzgwJqVnDYlEFhhNrsMJ1lMEaRaVKbbALRNQucAsMwnR4FzUdl66Rez0ggDmh2qGVf81iyFPiHhQGh+gIdUBfGxnAR8eM3TD5KBr3GdWi6o9+kFS2gcOQ
DbfN025aUMQjGDBiqxiipSlpzsqlwlWQz93Wrdq+O/kjfPRG8/TKp9QooKJNw8Lyvy9geBKNPN2NDVBXfoGvbPk/oFxaxRi1ALkrhLIVEy/Jj/a+WrsdAZNIgxamxuPvv9APj/agZuZXdu03m7PvvjciHP5+oQ7qER2+5W+0fJ39A9+JdCjxldRu0LkVQz9dYP7w300E
KUP1Ao/l4IfxljBZGHGOWCvSXpJ6Kj6A2ddlQ9d1diSxBP6R/cBPnMl4z0bSKLPxQ9nRDpDPUgOFT5nfc9w/Rdduvhf3/B/T06dd2XDC06Y4zzDpl/SpVA360MXUvXvcvwtRk698JWOsuTDm5/r74/g5XQnz4bJXeQwG5wHtWvz3qBREQRCizbJSIfNEf9qYRAsiX4TK
3QwJt7+gamRSY/JjXvKzmhChfIy13XEbuZsHfpXHAPD5TKE0KE6dlRts6Ur1BesjEvJYPUwCKrKjMqqAQxez3gQVRd7N4ESCCJPcqQLKjKyd0z2ftuiaxt+p1vz9P5XqfmTHWDXwDn/JA+yterIRdwLrIHxKgxraGiD2XKvRS1z5FsX9zD9LfMO/1EAzQJMtgi6S/GI4
z1UTnUdCeX51g0IEBxMPfBLVWlQY1Tq3imLKcIdOwPGrPUz+LbTq53ZTOA+t6rX6ydv2UzJOKbar1XAhb6+YjObEh59KT3XnHqpWjcK4tR8S3eF73nKv4u6lge1gLfounwRARelTLVTvcVHJm45b7d8f36nL6uOrelZ7zJAPvNURO3ZOVVkgvmef5fylzckkxw5L2uPz
jK5g5/j346XSpvvN9pufK3vi3+xBuoOej4MUSiIN6xKF8wNRBWtEQ+aG3AuQ5T0bRqT6RvdNXgGLAmLIKLCKLPZsswhDb7OnNRnfVjwAfng7kkXyjzkDyZ1GnyjseaGA5YcXFxPf0gOFwXClzDe9OmJitkZGAeVkrZBlZwKzHHcwdL1V85iZn4ufUJyDAUjyAbBNjbbZ
b7z3dT2p+Oy9uBfb+SNM0sVGLFgj5JpCkD445vDa2DGlC4SkQlIolQbVBAhVU743RNZE9V/18t0eX2eb09QzPP0ZufEbdtavd7294p/dNdfq7LNbH9M1T9TG5CA3ctzL5jY+8ruDUynn1TmmMydNkNvt6aWU4U5iOxTXzTVmp6+OptB932ZTn/R91JqOXA4TBphBVUUW
YZummHML5XwOYmShHzP6rrK1L4WNdEQC6H4+jHqUz9DlmthmLpMfn426+9BbC3ucsJ8jpFVVXPVVVVSqvoFhFVbCpJJQEkklpGM+l4fsKYEPG9xYn3r2BU51+jDqzywxw/k6VM2FRYOvsFWDcsjcqZMUp1uh3W6Md5UIHi+h+Pw7NbdvY9SH644jm3ro3CfcmQurfYEf
6+2jG9T/cNA0L3ZZlaufVEuv8Y3/4u5IpwoSH6vB8oA=
EOF
    else
        # @note openssl has limited support for reading long lines for base64, 80 characters is maximum
        # @note Payload was built with make_duti32.sh
        openssl base64 -d << EOF | bzip2 -d -c > "${TMP_DIR}/duti"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EOF
    fi
    chmod 755 "${TMP_DIR}/duti"
}
function cleanup_duti() {
    if [[ ! -z "${TMP_DIR}" ]] ; then
        rm -rf "${TMP_DIR}"
    fi
}
trap cleanup_duti EXIT
if ! command_exists duti ; then
    extract_duti
    export PATH="${TMP_DIR}:${PATH}"
fi

echo -n "Set ${BUNDLE_ID} as viewer for:"
TAB_SYMBOL="$(echo -e '\t')"
for ext in $(cat "${APP_PATH}/Contents/Info.plist" | egrep "${TAB_SYMBOL}${TAB_SYMBOL}${TAB_SYMBOL}${TAB_SYMBOL}<string>[a-z0-9]{3,5}</string>" | sed 's|.*<string>\(.*\)</string>|\1|') ; do
    echo -n " ${ext}"
    duti -s ${BUNDLE_ID} ${ext} viewer
done
echo
